/* BdfServer - Copyright (c) 2006-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.api.users;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.tools.roles.PermissionSummaryBuilder;
import net.fichotheque.EditOrigin;
import net.fichotheque.corpus.Fiches;
import net.fichotheque.selection.FicheQuery;
import net.fichotheque.sphere.Redacteur;
import net.mapeadores.util.localisation.UserLangContext;
import net.mapeadores.util.text.StringUtils;


/**
 *
 * @author Vincent Calame
 */
public interface BdfUser extends UserLangContext {

    public Redacteur getRedacteur();

    public BdfUserPrefs getPrefs();

    public FicheQuery getFicheQuery();

    public String getSortType();

    public Fiches getSelectedFiches();

    public void setSelectedFiches(Fiches fiches);

    /**
     * Retourne la valeur d'un paramètre stocké le temps de la session.
     * L'instance de Bdfuser se contente d'être un lieu de stockage, il ne fait
     * rien avec les valeurs en question. C'est aux applications utilisant ces
     * paramètres d'utiliser une convention de nommage évitant les carambolages.
     */
    public Object getParameterValue(String parameterName);

    public void putParameter(String parameterName, Object parameterValue);

    public EditOrigin newEditOrigin(String source);

    public default String format(int integer) {
        return StringUtils.toString(integer, getFormatLocale());
    }

    public default PermissionSummary getPermissionSummary(BdfServer bdfServer) {
        return PermissionSummaryBuilder.build(bdfServer, this);
    }

}
