/* BdfServer - Copyright (c) 2012-2015 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.tools.exportation.table;

import fr.exemole.bdfserver.api.exportation.table.FicheTableParameters;
import fr.exemole.bdfserver.api.exportation.table.TableExportParameters;
import net.fichotheque.exportation.table.TableExportConstants;


/**
 *
 * @author Vincent Calame
 */
public class TableExportParametersBuilder {

    private String tableExportName = null;
    private short headerType = TableExportConstants.COLUMNTITLE_HEADER;
    private FicheTableParameters ficheTableParameters = BdfTableExportUtils.NONE_FICHETABLEPARAMETERS;

    public TableExportParametersBuilder() {
    }

    public void setTableExportName(String tableExportName) {
        this.tableExportName = tableExportName;
    }

    public void setHeaderType(short headerType) {
        if ((headerType < 0) || (headerType > TableExportConstants.COLUMNKEY_HEADER)) {
            throw new IllegalArgumentException("wrong type value");
        }
        this.headerType = headerType;
    }

    public void setFicheTableParameters(FicheTableParameters ficheTableParameters) {
        if (ficheTableParameters == null) {
            throw new IllegalArgumentException("ficheTableParameters is null");
        }
        this.ficheTableParameters = ficheTableParameters;
    }

    public TableExportParameters toTableExportParameters() {
        return new InternalTableExportParameters(tableExportName, headerType, ficheTableParameters);
    }


    private static class InternalTableExportParameters implements TableExportParameters {

        private final String tableExportName;
        private final short headerType;
        private final FicheTableParameters ficheTableParameters;

        private InternalTableExportParameters(String tableExportName, short headerType, FicheTableParameters ficheTableParameters) {
            this.tableExportName = tableExportName;
            this.headerType = headerType;
            this.ficheTableParameters = ficheTableParameters;
        }

        @Override
        public String getTableExportName() {
            return tableExportName;
        }

        @Override
        public FicheTableParameters getDefaulFicheTableParameters() {
            return ficheTableParameters;
        }

        @Override
        public short getHeaderType() {
            return headerType;
        }

    }

}
