/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.commands.BdfCommandUtils;
import fr.exemole.bdfserver.tools.instruction.AbstractBdfCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import java.text.ParseException;
import net.fichotheque.thesaurus.Motcle;
import net.fichotheque.thesaurus.ThesaurusEditor;
import net.fichotheque.tools.parsers.TypoParser;
import net.fichotheque.utils.ThesaurusUtils;
import net.mapeadores.util.localisation.Lang;
import net.mapeadores.util.request.RequestMap;
import net.mapeadores.util.text.LabelChange;
import net.mapeadores.util.text.TypoOptions;


/**
 *
 * @author Vincent Calame
 */
public class LabelChangeCommand extends AbstractBdfCommand {

    public final static String COMMANDNAME = "LabelChange";
    public final static String COMMANDKEY = "_ THS-11";
    public final static String LABEL_PARAMPREFIX = "label/";
    public final static String BABELIEN_LANG_PARAMNAME = "babelienlang";
    public final static String BABELIEN_LABEL_PARAMNAME = "babelienlabel";
    private Motcle motcle;
    private LabelChange motcleLabelChange;
    private Lang babelienLang;
    private String babelienLabel;

    public LabelChangeCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        boolean done = false;
        ThesaurusEditor thesaurusEditor = editSession.getFichothequeEditor().getThesaurusEditor(motcle.getThesaurus().getSubsetKey());
        if (motcleLabelChange != null) {
            done = ThesaurusUtils.changeMotcleLabelHolder(thesaurusEditor, motcle, motcleLabelChange);
        } else if (babelienLabel != null) {
            TypoOptions typoOptions = TypoOptions.getTypoOptions(babelienLang.toLocale());
            done = thesaurusEditor.putLabel(motcle, babelienLang, TypoParser.parseTypo(babelienLabel, typoOptions));
        }
        if (done) {
            setDone("_ done.thesaurus.labelchange");
        }
        putResultObject(THESAURUS_OBJ, motcle.getThesaurus());
        putResultObject(MOTCLE_OBJ, motcle);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        motcle = BdfInstructionUtils.getMandatoryMotcle(fichotheque, requestMap);
        checkSubsetAdminPermission(motcle.getThesaurus());
        if (ThesaurusUtils.isBabelienType(motcle.getThesaurus())) {
            babelienLabel = getMandatory(BABELIEN_LABEL_PARAMNAME);
            String langString = getMandatory(BABELIEN_LANG_PARAMNAME).trim();
            if (langString.length() > 0) {
                try {
                    babelienLang = Lang.parse(langString);
                } catch (ParseException lie) {
                    setError("_ error.wrong.lang", langString);
                    return false;
                }
            }
        } else {
            motcleLabelChange = BdfCommandUtils.getLabelChange(requestMap, LABEL_PARAMPREFIX, true);
        }
        return true;
    }

}
