/* BdfServer_Commands - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.commands.thesaurus;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.BdfInstructionException;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.commands.AbstractPhrasesCommand;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import net.fichotheque.thesaurus.Thesaurus;
import net.fichotheque.thesaurus.metadata.ThesaurusMetadataEditor;
import net.mapeadores.util.request.RequestMap;


/**
 *
 * @author Vincent Calame
 */
public class ThesaurusPhrasesCommand extends AbstractPhrasesCommand {

    public final static String COMMANDNAME = "ThesaurusPhrases";
    public final static String COMMANDKEY = "_ THS-02";
    private Thesaurus thesaurus;

    public ThesaurusPhrasesCommand(BdfServer bdfServer, RequestMap requestMap) {
        super(bdfServer, requestMap);
    }

    @Override
    public boolean needSynchronisation() {
        return true;
    }

    @Override
    protected void doCommand() throws BdfInstructionException {
        initEditSession(Domains.THESAURUS + "/" + COMMANDNAME);
        ThesaurusMetadataEditor thesaurusMetadataEditor = editSession.getFichothequeEditor().getThesaurusEditor(thesaurus.getSubsetKey()).getThesaurusMetadataEditor();
        boolean done = false;
        if (update(thesaurusMetadataEditor)) {
            done = true;
        }
        if (done) {
            setDone("_ done.thesaurus.thesaurusphrases");
        }
        putResultObject(THESAURUS_OBJ, thesaurus);
    }

    @Override
    protected boolean checkParameters() throws BdfInstructionException {
        thesaurus = BdfInstructionUtils.getMandatoryThesaurus(fichotheque, requestMap);
        checkSubsetAdminPermission(thesaurus);
        boolean done = checkPhrasesParameters();
        return done;
    }

}
