/* BdfServer_Html - Copyright (c) 2020 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.html.consumers;

import java.util.function.BiConsumer;
import net.mapeadores.util.html.HtmlPrinter;


/**
 *
 * @author Vincent Calame
 */
public class SelectOption implements BiConsumer<HtmlPrinter, Object> {

    private final String value;
    private String text;
    private String textLocKey;

    public SelectOption(String value) {
        this.value = value;
    }

    public SelectOption textLocKey(String textLocKey) {
        this.textLocKey = textLocKey;
        return this;
    }

    public SelectOption text(String text) {
        this.text = text;
        return this;
    }

    public static SelectOption init(String value) {
        return new SelectOption(value);
    }

    @Override
    public void accept(HtmlPrinter hp, Object object) {
        boolean selected = false;
        if (object != null) {
            if (object instanceof Boolean) {
                selected = (Boolean) object;
            } else {
                selected = (object.equals(value));
            }
        }
        hp
                .OPTION(value, selected);
        if (text != null) {
            hp
                    .__escape(text);
        } else if (textLocKey != null) {
            hp
                    .__localize(textLocKey);
        }
        hp
                ._OPTION();
    }

}
