/* BdfServer_HtmlProducers - Copyright (c) 2010-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package fr.exemole.bdfserver.htmlproducers.edition;

import fr.exemole.bdfserver.api.BdfServer;
import fr.exemole.bdfserver.api.instruction.ProducerParameters;
import fr.exemole.bdfserver.api.interaction.Domains;
import fr.exemole.bdfserver.api.interaction.domains.CorpusDomain;
import fr.exemole.bdfserver.api.interaction.domains.EditionDomain;
import fr.exemole.bdfserver.api.interaction.domains.MainDomain;
import fr.exemole.bdfserver.api.roles.PermissionSummary;
import fr.exemole.bdfserver.api.roles.SatelliteOpportunities;
import fr.exemole.bdfserver.api.users.BdfUser;
import fr.exemole.bdfserver.html.BdfHtmlConstants;
import fr.exemole.bdfserver.html.BdfServerHtmlProducer;
import fr.exemole.bdfserver.html.consumers.Button;
import fr.exemole.bdfserver.html.consumers.SatelliteTree;
import fr.exemole.bdfserver.tools.BH;
import fr.exemole.bdfserver.tools.BdfServerUtils;
import fr.exemole.bdfserver.tools.instruction.BdfInstructionUtils;
import fr.exemole.bdfserver.tools.roles.PermissionSummaryBuilder;
import fr.exemole.bdfserver.tools.ui.components.UiComponentUtils;
import fr.exemole.bdfserver.tools.ui.components.UiSummary;
import net.fichotheque.corpus.FicheMeta;
import net.mapeadores.util.html.HA;
import net.mapeadores.util.html.HtmlConstants;


/**
 *
 * @author Vincent Calame
 */
public class FicheResultHtmlProducer extends BdfServerHtmlProducer {

    private final static Button REFRESH_BUTTON = Button.link(BH.domain(Domains.MAIN).page(MainDomain.FICHES_PAGE).param(MainDomain.FICHES_RELOAD_PARAMNAME, "1").toString()).target(BdfHtmlConstants.LIST_FRAME).action("action-Refresh").titleMessage("_ link.global.refresh").tooltipMessage("_ link.main.fiches_update");
    private final FicheMeta ficheMeta;
    private final Button linkButton = Button.link();

    public FicheResultHtmlProducer(ProducerParameters producerParameters, FicheMeta ficheMeta) {
        this(producerParameters.getBdfServer(), producerParameters.getBdfUser(), ficheMeta);
    }

    public FicheResultHtmlProducer(BdfServer bdfServer, BdfUser bdfUser, FicheMeta ficheMeta) {
        super(bdfServer, bdfUser);
        this.ficheMeta = ficheMeta;
        addThemeCss("edition.css");
    }

    @Override
    public void printHtml() {
        String fichePath = BdfInstructionUtils.getFicheGetLink(ficheMeta, "html");
        PermissionSummary permissionSummary = PermissionSummaryBuilder.build(bdfServer, bdfUser);
        SatelliteOpportunities satelliteOpportunities = BdfServerUtils.getSatelliteOpportunities(ficheMeta, permissionSummary);
        boolean withSatellites = hasSatellites(satelliteOpportunities);
        UiSummary uiSummary = UiComponentUtils.summarize(bdfServer.getUiManager().getMainUiComponents(ficheMeta.getCorpus()));
        String editionHref = BH.domain(Domains.EDITION).page(EditionDomain.FICHE_CHANGE_PAGE).subsetItem(ficheMeta).toString();
        String addendaHref = BH.domain(Domains.CORPUS).page(CorpusDomain.FICHE_ADDENDA_PAGE).subsetItem(ficheMeta).toString();
        start();
        this
                .DIV("edition-Page edition-result-Page")
                .__(printCommandMessageUnit())
                .NAV("edition-Toolbar")
                .__(REFRESH_BUTTON)
                .__(link(editionHref, "action-FicheEdit", "_ link.edition.fichechange_short", "_ link.edition.fichechange_back", null))
                .__if(uiSummary.withAddendaInclude(), link(addendaHref, "action-FicheAddenda", "_ link.edition.ficheaddenda_short", "_ link.edition.ficheaddenda_long", null))
                .__(link(fichePath, "action-FicheDisplay", "_ link.global.display", "_ link.fiches.fiche_blank", HtmlConstants.BLANK_TARGET))
                .__(printSatelliteButton(withSatellites, satelliteOpportunities))
                ._NAV()
                .IFRAME(HA.src(fichePath).classes("edition-Unit"))
                .P()
                .A(HA.href(fichePath))
                .__localize("_ link.fiches.fiche_long")
                ._A()
                ._P()
                ._IFRAME()
                ._DIV();
        end();
    }

    private boolean hasSatellites(SatelliteOpportunities satelliteOpportunities) {
        if (satelliteOpportunities.onlyReadAllowed()) {
            return false;
        }
        return !satelliteOpportunities.getEntryList().isEmpty();
    }

    private boolean printSatelliteButton(boolean withSatellites, SatelliteOpportunities satelliteOpportunities) {
        if (!withSatellites) {
            return false;
        }
        this
                .DETAILS("tools-Details")
                .SUMMARY("edition-result-Summary")
                .SPAN("edition-result-SummaryContent")
                .__localize("_ link.global.rattachement")
                ._SPAN()
                ._SUMMARY()
                .__(SatelliteTree.init(workingLang, formatLocale).current(ficheMeta, satelliteOpportunities))
                ._DETAILS();
        return true;
    }

    private Button link(String href, String action, String titleLocKey, String tooltipLocKey, String target) {
        return linkButton.href(href).action(action).titleMessage(titleLocKey).tooltipMessage(tooltipLocKey).target(target);
    }

}
