/* FichothequeLib_API - Copyright (c) 2019-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.utils;

import java.util.function.Predicate;
import net.fichotheque.Fichotheque;
import net.fichotheque.Subset;
import net.fichotheque.SubsetItem;
import net.fichotheque.corpus.FicheMeta;
import net.fichotheque.extraction.ExtractionContext;
import net.fichotheque.extraction.ExtractionEngine;
import net.fichotheque.extraction.LinkAnalyser;
import net.fichotheque.extraction.ModeResolver;
import net.fichotheque.extraction.run.ExtractorProvider;
import net.mapeadores.util.localisation.LangContext;
import net.mapeadores.util.localisation.MessageLocalisationProvider;
import net.mapeadores.util.mimetype.MimeTypeResolver;
import net.fichotheque.corpus.Fiches;


/**
 *
 * @author Vincent Calame
 */
public final class ExtractionUtils {

    public final static ExtractionEngine EMPTY_EXTRACTIONENGINE = new EmptyExtractionEngine();

    private ExtractionUtils() {

    }

    public static ExtractionContext derive(ExtractionContext extractionContext, Predicate<FicheMeta> fichePredicate) {
        return new DeriveExtractionContext(extractionContext, fichePredicate);
    }

    public static ExtractionContext derive(ExtractionContext extractionContext, LangContext langContext) {
        return new DeriveExtractionContext(extractionContext, langContext);
    }


    private static class DeriveExtractionContext implements ExtractionContext {

        private final ExtractionContext originExtractionContext;
        private final Predicate<FicheMeta> fichePredicate;
        private final LangContext langContext;

        private DeriveExtractionContext(ExtractionContext originExtractionContext, Predicate<FicheMeta> fichePredicate) {
            this.originExtractionContext = originExtractionContext;
            this.langContext = originExtractionContext.getLangContext();
            this.fichePredicate = fichePredicate;
        }

        private DeriveExtractionContext(ExtractionContext originExtractionContext, LangContext langContext) {
            this.originExtractionContext = originExtractionContext;
            this.langContext = langContext;
            this.fichePredicate = originExtractionContext.getFichePredicate();
        }

        @Override
        public Fichotheque getFichotheque() {
            return originExtractionContext.getFichotheque();
        }

        @Override
        public MessageLocalisationProvider getMessageLocalisationProvider() {
            return originExtractionContext.getMessageLocalisationProvider();
        }

        @Override
        public LangContext getLangContext() {
            return langContext;
        }

        @Override
        public LinkAnalyser getLinkAnalyser() {
            return originExtractionContext.getLinkAnalyser();
        }

        @Override
        public ExtractorProvider getExtractorProvider() {
            return originExtractionContext.getExtractorProvider();
        }

        @Override
        public MimeTypeResolver getMimeTypeResolver() {
            return originExtractionContext.getMimeTypeResolver();
        }

        @Override
        public ModeResolver getModeResolver() {
            return originExtractionContext.getModeResolver();
        }

        @Override
        public Predicate<Subset> getSubsetAccessPredicate() {
            return originExtractionContext.getSubsetAccessPredicate();
        }

        @Override
        public Predicate<FicheMeta> getFichePredicate() {
            return fichePredicate;
        }

        @Override
        public Fiches getSelectedFiches() {
            return originExtractionContext.getSelectedFiches();
        }

    }


    private static class EmptyExtractionEngine implements ExtractionEngine {

        private EmptyExtractionEngine() {

        }

        @Override
        public String getExtractionString(SubsetItem subsetItem, Predicate<SubsetItem> predicate) {
            return null;
        }

    }

}
