/* FichothequeLib_Tools - Copyright (c) 2012-2021 Vincent Calame - Exemole
 * Logiciel libre donné sous triple licence :
 * 1) selon les termes de la CeCILL V2
 * 2) selon les termes de l’EUPL V.1.1
 * 3) selon les termes de la GNU GPLv3
 * Voir le fichier licences.txt
 */


package net.fichotheque.tools.extraction;

import java.io.IOException;
import java.util.function.Predicate;
import net.fichotheque.SubsetItem;
import net.fichotheque.extraction.ExtractionContext;
import net.fichotheque.extraction.ExtractionEngine;
import net.fichotheque.extraction.ExtractionSource;
import net.fichotheque.extraction.def.ExtractionDef;
import net.fichotheque.tools.extraction.builders.BuilderUtils;
import net.fichotheque.utils.EligibilityUtils;
import net.fichotheque.utils.ExtractionUtils;
import net.fichotheque.xml.extraction.ExtractionXMLPart;
import net.mapeadores.util.localisation.Message;
import net.mapeadores.util.logging.CategorizedMessageEntry;
import net.mapeadores.util.logging.MessageLog;
import net.mapeadores.util.xml.XMLUtils;


/**
 *
 * @author Vincent Calame
 */
public class XmlExtractionEngine implements ExtractionEngine {

    private final ExtractionDef extractionDef;
    private final ExtractionContext extractionContext;
    private final MessageLog messageLog;

    public XmlExtractionEngine(ExtractionDef extractionDef, ExtractionContext extractionContext, MessageLog messageLog) {
        this.extractionDef = extractionDef;
        this.extractionContext = extractionContext;
        this.messageLog = messageLog;
    }

    @Override
    public String getExtractionString(SubsetItem subsetItem, Predicate<SubsetItem> predicate) {
        if (extractionDef == null) {
            StringBuilder buf = new StringBuilder();
            buf.append("<extraction>");
            try {
                appendLog(buf);
            } catch (IOException ioe) {
            }
            buf.append("</extraction>");
            return buf.toString();
        }
        ExtractionContext derive = ExtractionUtils.derive(extractionContext, EligibilityUtils.toFichePredicate(predicate));
        ExtractionSource extractionSource = BuilderUtils.getExtractionSource(subsetItem, derive, extractionDef);
        return ExtractionXMLPart.toString(derive, extractionDef, extractionSource, false, true);
    }

    private void appendLog(Appendable buf) throws IOException {
        for (MessageLog.LogGroup logGroup : messageLog.getLogGroupList()) {
            for (CategorizedMessageEntry entry : logGroup.getEntryList()) {
                Message message = entry.getMessage();
                buf.append("<message category=\"");
                buf.append(entry.getCategory());
                buf.append("\" key=\"");
                buf.append(message.getMessageKey());
                buf.append("\">");
                Object[] values = message.getMessageValues();
                for (Object value : values) {
                    buf.append("<value>");
                    XMLUtils.writeEscape(buf, value.toString());
                    buf.append("</value>");
                }
                buf.append("</message>");
            }
        }
    }

}
